package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@(!`0D```````````(`/@`!````(!Y```````!``````````'"[````
M`````````$``.``&`$``%P`6``8````%````0`````````!``$```````$``
M0```````4`$```````!0`0````````@``````````P````0```"0`0``````
M`)`!0```````D`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````.*P````````XK``````````
M`!````````$````&````Z+````````#HL%```````.BP4```````<`@`````
M``"@#0``````````$````````@````8```"0M0```````)"U4```````D+50
M``````"P`0```````+`!````````"``````````$````!````*@!````````
MJ`%```````"H`4```````!@`````````&``````````$`````````"]L:6)E
M>&5C+VQD+65L9BYS;RXQ``````@````$`````0```$9R965"4T0`8#<)`&$`
M``!H````````````````````+0````````!:````60```$<`````````````
M`&$`````````4P````@`````````.0```$4````\````#P```#@```!-````
M1````&(````````````````````O````5P```#<````"`````````"0```!"
M````.P```%\```!*````!0```&8```!&````'`````````!,````8P```%$`
M````````,````%X`````````3@```"<```!=````4````!<```!!````7```
M`"4`````````,0```&0`````````*@```"X`````````2P```"$`````````
M``````````!G````90```#8```!6````6P```!\```````````````````!5
M````-0```$,```!4````6`````X`````````$0````0`````````````````
M```Z`````````"`````6`````````$````!@````````````````````````
M````````````````````````````````````````````````````````````
M"P``````````````````````````````````````````````#```````````
M`````````!(````#````&@`````````````````````````4````$````!D`
M```!````"@`````````>```````````````````````````````)````````
M```````````````````````5```````````````R````````````````````
M*```````````````#0```````````````````#X`````````/P``````````
M````/0`````````L`````````!T```!)````!P`````````S`````````"L`
M```T`````````"(`````````*0```$\````&````$P`````````8````````
M``````!2`````````"8````````````````````C````2````!L`````````
M`````````````````````````````````````,$#```1``T`(+%0```````(
M``````````P````2````;!I```````"-`````````!<````2````?!I`````
M``"(!P```````"D````1`!0`8+E0```````!`````````-4#```2``H`$"9`
M``````"/`0```````$`````2````C!I``````````````````$@````1`/'_
MD+50`````````````````%$````2````G!I``````````````````%@````2
M````K!I```````"=`P```````&8````2````O!I``````````````````&T`
M```2````S!I```````"G`````````'D````2````W!I`````````````````
M`((````2````[!I``````````````````(D````2````_!I````````8`0``
M`````.(#```2``H`8"-````````%`````````.\"```2````#!M````````1
M`````````)H````1`!0`:+E0```````(`````````*0````2````'!M`````
M```*!P```````+,````1`!0`<+E0```````(`````````+T````2````+!M`
M`````````````````,,````2````/!M```````!W`````````/,#```2``H`
MH"=```````!%`````````,L````2````3!M```````#P`0````````$$```2
M``H`,"5```````#4`````````-D````2````7!M````````6`````````-\`
M```1`!0`>+E0```````!`````````#($```2``@`2!I`````````````````
M`.P````2````;!M````````9!0```````/<````2````?!M```````"=````
M``````0!```2````C!M```````!#`0```````!(!```1`!0`@+Y0```````(
M`````````!H!```2````G!M```````!8`@```````"4!```@````````````
M``````````````T$```2``H`<"-```````!V`0```````#T!```2````K!M`
M```````A`````````!H$```2``H`($Q```````#+`@```````#`$```2``H`
M4!]````````4`````````&`#```1``T`Z+!0```````(`````````(\#```2
M``H`(!Y```````",`````````$P!```2````O!M``````````````````%(!
M```2````S!M```````!F`````````%D!```2````W!M````````(````````
M`&$!```2````[!M``````````````````&8!```2````_!M```````!V````
M`````'(!```2````#!Q````````Q`````````#H#```2````'!Q````````Q
M`````````'H!```2````+!Q``````````````````#@$```2``H`H$!`````
M``#."````````($!```2````/!Q````````,`````````(D!```2````3!Q`
M```````L!````````)(!```1`!0`@+E0```````(`````````&L#```2````
M7!Q````````,`````````$4$```2``H`P$I```````!M`````````*4!```1
M`!0`B+E0```````!`````````$(#```2````;!Q```````!5`````````+,!
M```2````?!Q```````#V`@```````,,!```1`!0`D+E0```````(````````
M`(H#```0`/'_6+E0`````````````````-,!```2````C!Q`````````````
M`````%$$```2``H`($]````````A`@```````'(#```2````G!Q````````"
M`````````%8$```2``H`H#]```````#[`````````&@$```2``H`L")`````
M``"F`````````-H!```2````K!Q````````*`````````.(!```1`!0`F+E0
M```````!`````````.T!```2````O!Q``````````````````,T$```2````
MS!Q````````>`````````/0!```2``L`B%%``````````````````/H!```2
M````W!Q````````X$`````````@"```2````[!Q```````!+`0```````'P#
M```2````_!Q````````O`````````!`"```2````#!U```````!"````````
M`$T!```2````'!U``````````````````'X$```1``T`&+%0```````(````
M`````"`"```2````+!U````````F`````````"L"```2````/!U`````````
M`````````(,#```0`/'_6+E0`````````````````#("```1`/'_:+=0````
M`````````````)8#```0`/'_B+Y0`````````````````$@"```1`!0`F;E0
M```````!`````````%,"```1`!0`H+E0```````3`````````)($```2``H`
M`$Q````````>`````````'X#```2````3!U````````V`````````&("```2
M````7!U```````")`````````*X$```2``H`\"1````````[`````````'D"
M```1`!0`N+E0```````(`````````+L$```2``H`X#Y````````<````````
M`'\"```1`!0`P+E0```````(`````````(H"```2````;!U```````#,`@``
M`````)@"```1`!0`R+E0```````(`````````*4"```2````?!U````````4
M`````````*P"```2````C!U``````````````````+$"```2````G!U`````
M``!*`````````+@"```2````K!U```````"F`````````,$"```@````````
M`````````````````-4"```2````O!U````````5`````````.,"```2````
MS!U````````V`````````/8"```2````W!U``````````````````/P"```@
M`````````````````````````!(#```2````[!U````````5`````````!P#
M```2````_!U``````````````````,8#```1``P`H%1```````#J6P``````
M`!<#```2````#!Y````````.``````````!L:6)P97)L+G-O`%!E<FQ?8W)O
M86L`4&5R;%]S=E\R<'9?9FQA9W,`4$Q?<&5R;%]D97-T<G5C=%]L979E;`!M
M96UM;W9E`%]$64Y!34E#`&=E='!I9`!097)L7V%V7W-H:69T`&UE;6-P>0!0
M97)L7VUG7W-E=`!R96%D;&EN:P!G971U:60`4&5R;%]N97=84U]F;&%G<P!0
M3%]C;VUP8W8`<&5R;%]C;VYS=')U8W0`4$Q?<&%R<V5R`')M9&ER`')E861D
M:7(`4&5R;%]D;W5N=VEN9`!L<V5E:P!03%]D;U]U;F1U;7``<&5R;%]P87)S
M90!097)L7VYE=U-6<'8`4&5R;%]S=E]S971P=@!E;G9I<F]N`%!E<FQ?;F5W
M6%,`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]S>7-?:6YI=#,`;'-T
M870`<W1R<W1R`%]?97)R;W(`<F5A9`!?7U]R=6YE='EP90!S=')N8VUP`'5N
M;&EN:P!R96%L;&]C`'!E<FQ?<G5N`%]#=7)R96YT4G5N94QO8V%L90!03%]E
M>&ET7V9L86=S`&)O;W1?1'EN84QO861E<@!03%]C=7)S=&%C:VEN9F\`;65M
M<V5T`&]P96YD:7(`4$Q?=&%I;G1E9`!S=')C;7``7V9I;FD`<&5R;%]D97-T
M<G5C=`!S<')I;G1F`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V%L;&]C`&%C8V5S
M<P!?1TQ/0D%,7T]&1E-%5%]404),15\`4$Q?:6Y?979A;`!03%]M96UO<GE?
M=W)A<`!097)L7W-A=F5?9&5S=')U8W1O<E]X`%!,7V]P`%!,7W1O<%]E;G8`
M4&5R;%]A=E]F971C:`!03%]E=F%L7W)O;W0`<W1R;&5N`&]P96X`97AE8W9P
M`&-L;W-E9&ER`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R;0!0
M97)L7W-A9F5S>7-M86QL;V,`;6MD:7(`7U]R96=I<W1E<E]F<F%M95]I;F9O
M`'!E<FQ?9G)E90!C;&]S90!L:6)M+G-O+C0`;&EB8W)Y<'0N<V\N,P!S=')N
M8W!Y`'-T<F1U<`!L:6)U=&EL+G-O+C4`;&EB8RYS;RXV`%]?<')O9VYA;64`
M<W1R=&]K`%]I;FET7W1L<P!A=&5X:70`7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XQ,"XQ+VUA8V@O0T]210!N86UE
M7VQO861?;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`<&%R7V9I;F1P<F]G`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`'!A<E]M:W1M<&1I<@!P87)?8VQE
M86YU<`!M86EN`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!S:7IE7VQO861?;7E?<&%R7W!L`%A37TEN=&5R;F%L<U]005)?0TQ%
M05)35$%#2P!P87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60```!@N5````````4````$``````````````!HN5````````4````1````
M``````````!PN5````````4````3``````````````!XN5````````4````:
M``````````````"`N5````````4````S``````````````"(N5````````4`
M```V``````````````"0N5````````4````Y``````````````"8N5``````
M``4```!!``````````````"9N5````````4```!0``````````````"@N5``
M``````4```!1``````````````"XN5````````4```!6``````````````#`
MN5````````4```!8``````````````#(N5````````4```!:````````````
M``"`MU````````<````"``````````````"(MU````````<````#````````
M``````"0MU````````<````&``````````````"8MU````````<````(````
M``````````"@MU````````<````)``````````````"HMU````````<````*
M``````````````"PMU````````<````+``````````````"XMU````````<`
M```,``````````````#`MU````````<````-``````````````#(MU``````
M``<````.``````````````#0MU````````<````0``````````````#8MU``
M``````<````2``````````````#@MU````````<````4``````````````#H
MMU````````<````5``````````````#PMU````````<````7````````````
M``#XMU````````<````9````````````````N%````````<````<````````
M```````(N%````````<````=```````````````0N%````````<````>````
M```````````8N%````````<````@```````````````@N%````````<````C
M```````````````HN%````````<````H```````````````PN%````````<`
M```I```````````````XN%````````<````J``````````````!`N%``````
M``<````K``````````````!(N%````````<````L``````````````!0N%``
M``````<````M``````````````!8N%````````<````N``````````````!@
MN%````````<````O``````````````!HN%````````<````Q````````````
M``!PN%````````<````R``````````````!XN%````````<````T````````
M``````"`N%````````<````W``````````````"(N%````````<````X````
M``````````"0N%````````<````[``````````````"8N%````````<````]
M``````````````"@N%````````<```!```````````````"HN%````````<`
M``!"``````````````"PN%````````<```!#``````````````"XN%``````
M``<```!%``````````````#`N%````````<```!&``````````````#(N%``
M``````<```!'``````````````#0N%````````<```!(``````````````#8
MN%````````<```!)``````````````#@N%````````<```!+````````````
M``#HN%````````<```!,``````````````#PN%````````<```!3````````
M``````#XN%````````<```!4````````````````N5````````<```!9````
M```````````(N5````````<```!;```````````````0N5````````<```!<
M```````````````8N5````````<```!=```````````````@N5````````<`
M``!>```````````````HN5````````<```!@```````````````PN5``````
M``<```!A```````````````XN5````````<```!B``````````````!`N5``
M``````<```!D``````````````!(N5````````<```!E``````````````!0
MN5````````<```!G``````````````!(@^P(Z*\$``#H^C8``$B#Q`C#`/\U
M#IT0`/\E$)T0`)"0D)#_)0Z=$`!H`````.G@_____R4&G1``:`$```#IT/__
M__\E_IP0`&@"````Z<#_____)?:<$`!H`P```.FP_____R7NG!``:`0```#I
MH/____\EYIP0`&@%````Z9#_____)=Z<$`!H!@```.F`_____R76G!``:`<`
M``#I</____\ESIP0`&@(````Z6#_____)<:<$`!H"0```.E0_____R6^G!``
M:`H```#I0/____\EMIP0`&@+````Z3#_____):Z<$`!H#````.D@_____R6F
MG!``:`T```#I$/____\EGIP0`&@.````Z0#_____)9:<$`!H#P```.GP_O__
M_R6.G!``:!````#IX/[___\EAIP0`&@1````Z=#^____)7Z<$`!H$@```.G`
M_O___R5VG!``:!,```#IL/[___\E;IP0`&@4````Z:#^____)6:<$`!H%0``
M`.F0_O___R5>G!``:!8```#I@/[___\E5IP0`&@7````Z7#^____)4Z<$`!H
M&````.E@_O___R5&G!``:!D```#I4/[___\E/IP0`&@:````Z4#^____)3:<
M$`!H&P```.DP_O___R4NG!``:!P```#I(/[___\E)IP0`&@=````Z1#^____
M)1Z<$`!H'@```.D`_O___R46G!``:!\```#I\/W___\E#IP0`&@@````Z>#]
M____)0:<$`!H(0```.G0_?___R7^FQ``:"(```#IP/W___\E]IL0`&@C````
MZ;#]____)>Z;$`!H)````.F@_?___R7FFQ``:"4```#ID/W___\EWIL0`&@F
M````Z8#]____)=:;$`!H)P```.EP_?___R7.FQ``:"@```#I8/W___\EQIL0
M`&@I````Z5#]____);Z;$`!H*@```.E`_?___R6VFQ``:"L```#I,/W___\E
MKIL0`&@L````Z2#]____)::;$`!H+0```.D0_?___R6>FQ``:"X```#I`/W_
M__\EEIL0`&@O````Z?#\____)8Z;$`!H,````.G@_/___R6&FQ``:#$```#I
MT/S___\E?IL0`&@R````Z<#\____)7:;$`!H,P```.FP_/___R5NFQ``:#0`
M``#IH/S___\E9IL0`&@U````Z9#\____)5Z;$`!H-@```.F`_/___R56FQ``
M:#<```#I</S___\E3IL0`&@X````Z6#\____)4:;$`!H.0```.E0_/___R4^
MFQ``:#H```#I0/S__P````!!5$R-9PA54XL?2&/#A=M(C6S'$$B)+46@$`!^
M,TB+1PA(A<!T*DB)P4B)!9B2$`#K`TB)T0^V`83`=!0\+TB-40%U[DB)%7V2
M$`#KY69FD+B0M5``2(7`="M(B??H>O[__[^(44``Z'#^___HM_O__XG?2(GJ
M3(GFZ((P``")Q^BG_O__Z/+]___KUI"0D)"`/2F;$```54B)Y700ZSB02(/`
M"$B)!2V2$`#_TDB+!222$`!(BQ!(A=)UY+@`````2(7`=`J_:+%0`.@0X;__
MQ@7IFA```<G#9F9FD&9FD%6X`````$B%P$B)Y70/O@"Z4`"_:+%0`.CCX+__
M2(,].Y@0``!T&;@`````2(7`=`_)OV"W4`#IQ."__V9F9I#)PY"0D)"0D)"0
MD)"0D)"0NO-10`"^?!Q``+_]44``Z3C\__]F9F:09F9FD&9F9I!,B6PDZ$R)
M?"3X28G]2(E<)-!(B6PDV$F)]TR)9"3@3(ET)/!(@^PX2(7_='A,BS7<GA``
M387V=&P/M@=(B?F$P`^5PCP]#Y7`#[;`A<)T%TC_P0^V`83`#Y7"/#T/E<`/
MML"%PG7I28LNB<A,B?-$*>A(A>UT+DQCX&9FD&9FD$R)XDR)[DB)[^@._/__
MA<!U!T&`/"P]=#%(@\,(2(LK2(7M==LQP$B+7"0(2(ML)!!,BV0D&$R+;"0@
M3(MT)"A,BWPD,$B#Q#C#3"GS28U$+`%(P?L#08D?Z\QF9I!FD$B#[`@QP$B-
M="0$Z!#___](@\0(PV9F9I!F9F:09F:005<QP$%628G^055)B?5!5%532(/L
M"(`^/0^4P$D!Q4R)[^CE_/__2(UT)`1!B<=,B?<QP.C'_O__2(7`2(G%#X3F
M````2(G'Z+_\__]$B?I(.=`/@ZP```"+3"0$3(GUZP-(_\4/MD4`A,`/E<(\
M/0^5P`^VP(7"=>B)[TB+'8V=$`!!B<Q$*?="C7P_`N@)^O__2(7`2HD$X[K_
M____=%.+1"0$2(L59)T0`$B++,)!#[8&2?_&A,!T'3P]ZQ>0B$4`00^V%DC_
MQ4G_QH32B=!T!8#Z/77HQD4`/4C_Q9!!#[9%`$G_Q8A%`$C_Q83`=>XQTDB#
MQ`B)T%M=05Q!74%>05_#00^V10!)_\6(10!(_\6$P'3;00^V10!)_\6(10!(
M_\6$P'7<Z\=(BQW>G!``13'DZP=(@\,(0?_$2(,[`'7SBP6&F!``A<!T1D&-
M="0"2(L]MIP0`$AC]DC!Y@/H9OK__TB%P$B)!:"<$`"Z_____P^$>?___TEC
M[$2)X4C'1.@(`````$2)9"0$Z<G^__]!C7PD`L<%+9@0``$```!(8_](P><#
MZ.WX__](A<!(B<.Z_____P^$-/___TEC[$B+-4:<$`!(B<=(C13M`````.A"
M^/__2(G82(D=+)P0`.N89F9FD&9FD&9FD%-(B?M(@^P02(UT)`PQP$B)W^CY
M_/__2(7`=")(8U0D#$B+!?B;$`!(C1302(M""$B%P$B)`G302(/"".ON2(/$
M$%O#9F9FD&9F9I!F9F:02(E<).A(B6PD\$R)9"3X2('L.`@``$B-K"00!```
MZ,GW__^Y&5)``(G"OAY20``QP$B)[^@#^O__B<,QP(7;>$6Z``0``$B)YDB)
M[^C;]___B<,QP(7;>"V->P%(8__H^/?__TB)Q3'`2(7M=!A(8]M(B>9(B>](
MB=KHC??__\8$*P!(B>A(BYPD(`@``$B+K"0H"```3(ND)#`(``!(@<0X"```
MPV9F9I!F9I!F9I#I2____V9F9I!F9F:09F:0058QP$%505152(G]ORI20`!3
M2(GS2('L@`0``.B__/__2(LU:(T0`$B)[TF)Q.@I^/__2(7`=")(B>Z_,U)`
M`#'`Z+G\__](B>A(@<2`!```6UU!7$%=05[#2(GOZ*KY__](BS4OC1``2(G?
M08G&Z'CX__](A<!(B<-TO$R-K"2`````@#L`N*130`!(#T38387D=!-(B=Y,
MB>?HK/C__X7`#X2"````2(G?Z%SY__](8]")P4B+!=2,$``/M@`X1!K_=1G_
MR4ACP<8$&`!(BQ6[C!``#[82.%08_W3G0HU$,0$]_P,```^/2O___TB+#9N,
M$`!)B>A(B=J^7U-``$R)[S'`Z'+X__](B>9,B>_HE_C__X7`=1$/MT0D""4`
M\```/0"```!T'TB+-6>,$``Q_^BT]___2(7`2(G##X5`____Z>_^__^^`0``
M`$R)[^AV^/__A<!UT$R)[K\S4D``,<#HE_O__TR)[^B+]___Z=3^__]F9F:0
M9F:09F:0#[8'2(G^A,!T+8G"2(L%_8L0``^V`.L*#[812(G.A-)T%3C"2(U.
M`77N#[812(G/2(G.A-)UZTB)^,-F9I!FD%532(G[2(/L"$B%_W0(#[8O0(3M
M=1"_I%-``$B#Q`A;7>D6]___Z"'X__](C0P82(U1_T@YVG8Y2(L%D8L0``^V
M`#A!_W4,2/_*2#G:=B(X`G3T2#G:=AE(BPUQBQ``D.L(2/_*2#G:=@</M@$X
M`G7Q2#G:=$E(BPU3BQ``9F:02/_*2#G:=@</M@$X`G3Q2"G:,<E(C4("2#T`
M!```=Q5(_\)(B=Z_8+I0`.@\]O__N6"Z4`!(@\0(2(G(6UW#2(L]"HL0`$`Z
M+P^%3/___^E"____9F9FD&9F9I!F9F:02(/L.$B+!;TM``"_0%)``$B)!"1(
MBP6U+0``2(E$)`A(BP6Q+0``2(E$)!!(BP6M+0``2(E$)!@/MP6I+0``9HE$
M)"`QP.@%_/__,<"_25)``.CY^___,<"_45)``.CM^___,<"_6E)``.CA^___
M,<"_85)``.C5^___,<"_<5)``.C)^___,<"_*E)``.B]^___,<"_?5)``.BQ
M^___,<"_AU)``.BE^___,<"_D5)``.B9^___,<"_,U)``.B-^___,<"_FU)`
M`.B!^___,<"_I%)``.AU^___,<"_KU)``.A9^?__2(7`=`](B<:_AU)``#'`
MZ&7Y__\QP+_`4D``Z#GY__](A<!T#TB)QK_24D``,<#H1?G__[_=4D``,<#H
M&?G__TB%P$B)QK\J4D``=!TQP.@E^?__ONU20`"_85)``#'`Z!3Y__](@\0X
MPS'`O^]20`#HX_C__TB%P$B)QG0'OWU20`#KR$B-1"01OP!30`"Y"@```/Q(
MB<;SIG6X2(UT)!N_?5)``.NED$B#[`B+!6:)$`"#^/]T!4B#Q`C#,<"_?5)`
M`.B0^/__,=)(A<!T$0^V`(3`=`H\,+@!````#T70B=")%3")$`!(@\0(PV9F
M9I!F9F:09F:0051)B?Q(C7\X,?954TB![`@"``!,BP=(8\Z#Q@)(@\<(3(G"
M3(G`2,'B&$C!X`@E``#_`('B````_T@)PDR)P$G!Z!A(P>@()0#_``!("<))
M#[;`2<'H"$@)PDR)P$B)5,R(3(G"2,'@"$C!XA@E``#_`$G!Z`B!X@```/](
M"<),B<!)P>@0)0#_``!("<),"<*#_@](B53,D`^.=/___[X0````2&/&_\9(
MBY3$2/___T@SE,1P____2#.4Q!C___](,Y3$"/___TB-#!)(P>H?2`G1@^'_
M@_Y/2(E,Q(A^PTV+'"1-BTPD"$B-="2028ML)!!)BUPD&+_<O!N/3(G:3(G8
M3(G)2,'H&TC!X@5((>E("<),B<A(]]"#XO]((=A("<%,B<A)P>D"2`'*20-4
M)"!(P>`>2`-4)(A)"<%,B=E!@^'_3"')1(V"F7F"6DR)PDR)P$C!Z!M(P>(%
M2`G"3(G82/?0@^+_2"'H2`G!3(G82<'K`D@!RDC!X!Y,B<%(`=I(`Q9)"<-!
M@^/_2(/&"$2-DIEY@EI,B=),B=!(P>@;2,'B!4@)PDR)P$CWT(/B_TPAV4PA
MR$@)P4R)P$G!Z`)(`<I(P>`>3(G12`'J2`,620G`08/@_TB#Q@A,(<&-FIEY
M@EI(B=I(B=A(P>@;2,'B!4@)PDR)T$CWT(/B_TPAV$@)P4R)T$G!Z@)(`<I(
MP>`>2(G93`'*2`,620G"08/B_TB#Q@A,(=&-JIEY@EI(B>I(B>A(P>@;2,'B
M!4@)PDB)V$CWT(/B_TPAP$@)P4B)V$@!RDC!X!Y(P>L"3`':2`,62`G#@^/_
M2(GI2(/&"$@AV42-BIEY@EI,B<I,B<A(P>@;2,'B!4@)PDB)Z$CWT(/B_TPA
MT$@)P4B)Z$C![0)(`<I(P>`>3(G)3`'"2`,62`G%@^7_2(/&"$@AZ42-FIEY
M@EI,B=I,B=A(P>@;2,'B!4@)PDR)R$CWT(/B_T@AV$@)P4R)R$@!RDR)V4P!
MTD@#%DB#Q@A(P>`>2<'I`DD)P4&#X?]$C8*9>8):3"')3(G"3(G`2,'H&TC!
MX@5("<),B=A(]]"#XO]((>A("<%,B=A)P>L"2`'*2,'@'DR)P4@!VD@#%DD)
MPT&#X_](@\8(3"'91(V2F7F"6DR)TDR)T$C!Z!M(P>(%2`G"3(G`2/?0@^+_
M3"'(2`G!3(G`2<'H`D@!RDC!X!Y,B=%(`>I(`Q9(@\8(20G`08/@_TPAP8V:
MF7F"6DB)VDB)V$C!Z!M(P>(%2`G"3(G02/?0@^+_3"'82`G!3(G02<'J`D@!
MRDC!X!Y(B=E,`<I(`Q9)"<)!@^+_2(/&"$PAT8VJF7F"6DB)ZDB)Z$C!Z!M(
MP>(%2`G"2(G82/?0@^+_3"'`2`G!2(G82,'K`D@!RDC!X!Y(B>E,`=I(`Q9(
M"<.#X_](@\8(1(V*F7F"6DR)RDR)R$C!X@5(P>@;2"'92`G"2(GH2/?0@^+_
M3"'02`G!2(GH2,'M`D@!RDC!X!Y,B<E,`<)(`Q9("<6#Y?](@\8(2"'I1(V:
MF7F"6DR)VDR)V$C!Z!M(P>(%2`G"3(G(2/?0@^+_2"'82`G!3(G(2<'I`D@!
MRDC!X!Y,B=E,`=)(`Q9)"<%!@^'_2(/&"$2-@IEY@EI,B<),B<!(P>@;2,'B
M!4@)PDR)V$CWT(/B_TPAR4@AZ$@)P4R)V$G!ZP)(`<I(P>`>3(G!2`':2`,6
M20G#08/C_TB#Q@A,(=E$C9*9>8):3(G23(G02,'H&TC!X@5("<),B<!(]]"#
MXO],(<A("<%,B<!)P>@"2`'*2,'@'DR)T4@!ZD@#%DD)P$&#X/](@\8(3"'!
MC9J9>8):2(G:2(G82,'H&TC!X@5("<),B=!(]]"#XO],(=A("<%,B=!(`<I(
MP>`>2<'J`DP!RD@#%DD)PD&#XO](B=E(@\8(3"'1C:J9>8):2(GJ2(GH2,'H
M&TC!X@5("<)(B=A(]]"#XO],(<!("<%(B=A(P>L"2`'*2,'@'DB)Z4P!VD@#
M%D@)PX/C_TB#Q@A((=E$C8J9>8):3(G*3(G(2,'H&TC!X@5("<)(B>A(]]"#
MXO],(=!("<%(B>A(`<I,B<E,`<)(`Q9(@\8(2,'@'DC![0)("<6#Y?]$C9J9
M>8):2"'I3(G:3(G82,'H&TC!X@5("<),B<A(]]"#XO]((=A("<%,B<A)P>D"
M2`'*2,'@'DR)V4P!TD@#%DD)P4&#X?](@\8(3"')1(V"F7F"6DR)PDR)P$C!
MZ!M(P>(%2`G"3(G82/?0@^+_2"'H2`G!3(G82<'K`D@!RDC!X!Y(`=I(`Q9(
M@\8(20G#08/C_T2-DIEY@EI,B=!,B=)(P>H;2,'@!4@)T$R)PDPQVH/@_TPQ
MRD@!T$@!Z$@#!DB#Q@B-F*'KV6Y,B<!)P>@"2,'@'DD)P$B)VDB)V$C!ZAM(
MP>`%08/@_T@)T$R)TDPQPH/@_TPQVD@!T$P!R$@#!DB#Q@B-J*'KV6Y,B=!)
MP>H"2,'@'DD)PDB)ZDB)Z$C!ZAM(P>`%08/B_T@)T$B)VH/@_TPQTDPQPD@!
MT$P!V$@#!DB#Q@A$C8BAZ]EN2(G82,'K`DC!X!Y("<-,B<I,B<A(P>H;2,'@
M!8/C_T@)T$B)ZD@QVH/@_TPQTD@!T$P!P$@#!DB#Q@A$C9BAZ]EN2(GH2,'M
M`DC!X!Y("<5,B=I,B=A(P>H;2,'@!8/E_T@)T$R)RD@QZH/@_T@QVD@!T$P!
MT$@#!DB#Q@A$C8"AZ]EN3(G(2<'I`DC!X!Y)"<%,B<),B<!(P>H;2,'@!4&#
MX?]("=!,B=I,,<J#X/](,>I(`=!(`=A(`P9(@\8(1(V0H>O9;DR)V$G!ZP)(
MP>`>20G#3(G23(G02,'J&TC!X`5!@^/_2`G03(G"3#':@^#_3#'*2`'02`'H
M2`,&2(/&"(V8H>O9;DR)P$G!Z`)(P>`>20G`2(G:2(G808/@_TC!ZAM(P>`%
M2`G03(G23#'"@^#_3#':2`'03`'(2`,&2(/&"(VHH>O9;DR)T$G!Z@)(P>`>
M20G"2(GJ2(GH2,'J&TC!X`5!@^+_2`G02(G:3#'2@^#_3#'"2`'03`'82`,&
M2(/&"$2-B*'KV6Y(B=A(P>L"2,'@'D@)PTR)RDR)R$C!ZAM(P>`%@^/_2`G0
M2(GJ@^#_2#':3#'22`'03`'`2`,&2(/&"$2-F*'KV6Y(B>A(P>T"2,'@'D@)
MQ4R)VDR)V$C!ZAM(P>`%@^7_2`G03(G*2#'J@^#_2#':2`'03`'02`,&2(/&
M"$2-@*'KV6Y,B<A)P>D"2,'@'DD)P4R)PDR)P$C!ZAM(P>`%08/A_T@)T$R)
MVDPQRH/@_T@QZD@!T$@!V$@#!DB#Q@A$C9"AZ]EN3(G82<'K`DC!X!Y)"<-,
MB=),B=!(P>H;2,'@!4&#X_]("=!,B<),,=J#X/],,<I(`=!(`>A(`P9(@\8(
MC9BAZ]EN3(G`2<'H`DC!X!Y)"<!(B=I(B=A(P>H;2,'@!4&#X/]("=!,B=),
M,<*#X/],,=I(`=!,`<A(`P9(@\8(C:BAZ]EN3(G02<'J`DC!X!Y)"<)(B>I(
MB>A!@^+_2,'@!4C!ZAM("=!(B=I,,=*#X/],,<)(`=!,`=A(`P9(@\8(1(V(
MH>O9;DB)V$C!ZP)(P>`>2`G#3(G*3(G(2,'J&TC!X`6#X_]("=!(B>I(,=J#
MX/],,=)(`=!,`<!(`P9(@\8(1(V8H>O9;DB)Z$C![0)(P>`>2`G%3(G:3(G8
M2,'J&TC!X`6#Y?]("=!,B<I(,>J#X/](,=I(`=!,`=!(`P9(@\8(1(V`H>O9
M;DR)R$G!Z0)(P>`>20G!3(G"3(G`2,'J&TC!X`5!@^'_2`G03(G:3#'*@^#_
M2#'J2`'02`'82`,&2(/&"$2-D*'KV6Y,B=A)P>L"2,'@'DD)PTR)TDR)T$C!
MZAM(P>`%08/C_T@)T$R)PDPQVH/@_TPQRD@!T$@!Z$@#!DB#Q@B-F*'KV6Y,
MB<!(P>`>2<'H`DD)P$B)VDB)V$C!ZAM(P>`%08/@_T@)T$R)TDPQPH/@_TPQ
MVD@!T$P!R$@#!DB#Q@B-J*'KV6Y,B=!)P>H"2,'@'DD)PDB)ZDB)Z$&#XO](
MP>H;2,'@!4@)T$R)TDR)T4P)PDPAP8/@_T@AVD@)RD@!T$P!V$@#!DB#Q@A$
MC0PX2(G82,'K`DC!X!Y("<-,B<I,B<B#X_](P>H;2,'@!4@)T$B)VDB)V4P)
MTDPAT8/@_T@AZD@)RD@!T$P!P$@#!DB#Q@A$C1PX2(GH2,'M`DC!X!Y("<5,
MB=I,B=B#Y?](P>H;2,'@!4@)T$B)ZDB)Z4@)VD@AV8/@_TPARD@)RD@!T$P!
MT$@#!DB#Q@A$C00X3(G(2<'I`DC!X!Y)"<%,B<),B<!!@^'_2,'@!4C!ZAM(
M"=!,B<I,B<E(">I((>F#X/],(=I("<I(`=!(`=A(`P9(@\8(1(T4.$R)V$G!
MZP)(P>`>20G#3(G23(G008/C_TC!ZAM(P>`%2`G03(G:3(G93`G*3"')@^#_
M3"'"2`G*2`'02`'H2`,&2(/&"(T<.$R)P$G!Z`)(P>`>20G`2(G:2(G808/@
M_TC!X`5(P>H;2`G03(G"3(G!3`G:3"'9@^#_3"'22`G*2`'03`'(2`,&2(/&
M"(TL.$R)T$G!Z@)(P>`>20G"2(GJ2(GH08/B_TC!ZAM(P>`%2`G03(G23(G1
M3`G"3"'!@^#_2"':2`G*2`'03`'82`,&2(/&"$2-##A(B=A(P>L"2,'@'D@)
MPTR)RDR)R(/C_TC!ZAM(P>`%2`G02(G:2(G93`G23"'1@^#_2"'J2`G*2`'0
M3`'`2`,&2(/&"$2-'#A(B>A(P>T"2,'@'D@)Q4R)VDR)V(/E_TC!ZAM(P>`%
M2`G02(GJ2(GI2`G:2"'9@^#_3"'*2`G*2`'03`'02`,&2(/&"$2-!#A,B<A)
MP>D"2,'@'DD)P4R)PDR)P$&#X?](P>H;2,'@!4@)T$R)RDR)R8/@_T@)ZD@A
MZ4PAVD@)RD@!T$@!V$@#!DB#Q@A$C10X3(G82<'K`DC!X!Y)"<-,B=),B=!!
M@^/_2,'J&TC!X`5("=!,B=I,B=E,"<I,(<F#X/],(<)("<I(`=!(`>A(`P9(
M@\8(C1PX3(G`2<'H`DC!X!Y)"<!(B=I(B=A!@^#_2,'J&TC!X`5("=!,B<),
MB<&#X/],"=I,(=E,(=)("<I(`=!,`<A(`P9(@\8(C2PX3(G02<'J`DC!X!Y)
M"<)(B>I(B>A!@^+_2,'J&TC!X`5("=!,B=),B=%,"<),(<&#X/]((=I("<I(
M`=!,`=A(`P9(@\8(1(T,.$B)V$C!ZP)(P>`>2`G#3(G*3(G(@^/_2,'J&TC!
MX`5("=!(B=I(B=E,"=*#X/]((>I,(=%("<I(`=!,`<!(`P9(@\8(1(T<.$B)
MZ$C![0)(P>`>2`G%3(G:3(G8@^7_2,'J&TC!X`5("=!(B>I(B>E("=I((=F#
MX/],(<I("<I(`=!,`=!(`P9(@\8(1(T$.$R)R$G!Z0)(P>`>20G!3(G"3(G`
M08/A_TC!ZAM(P>`%2`G03(G*3(G)2`GJ@^#_3"':2"'I2`G*2`'02`'82`,&
M2(/&"$2-%#A,B=A)P>L"2,'@'DD)PTR)TDR)T$&#X_](P>H;2,'@!4@)T$R)
MVDR)V4P)RDPAR8/@_TPAPD@)RD@!T$@!Z$@#!DB#Q@B-'#A,B<!)P>@"2,'@
M'DD)P$B)VDB)V$&#X/](P>H;2,'@!4@)T$R)PDR)P4P)VDPAV8/@_TPATD@)
MRD@!T$P!R$@#!DB#Q@B-+#A,B=!)P>H"2,'@'DD)PDB)ZDB)Z$&#XO](P>H;
M2,'@!4@)T$R)TDR)T4P)PDPAP8/@_T@AVD@)RD@!T$P!V$@#!DB#Q@A$C0PX
M2(G82,'K`DC!X!Y("<-,B<I,B<B#X_](P>H;2,'@!4@)T$B)VDB)V4P)TDPA
MT8/@_T@AZD@)RKG6P6+*2`'03`'`2`,&2(/&"$2-'#A(B>A(P>T"2,'@'D@)
MQ4R)VDR)V$C!Z!M(P>(%@^7_2`G"3(G(2#'H@^+_2#'82`'"3(G(2<'I`DP!
MTD@#%DC!X!Y)"<%(@\8(08/A_T2-!`I,B<!,B<)(P>H;2,'@!4@)T$R)VDPQ
MRH/@_T@QZD@!T$@!V$@#!DB#Q@A$C10(3(G82,'@'DG!ZP))"<-,B=),B=!(
MP>H;2,'@!4&#X_]("=!,B<),,=J#X/],,<I(`=!(`>A(`P9(@\8(C1P(3(G`
M2<'H`DC!X!Y)"<!(B=I(B=A(P>H;2,'@!4&#X/]("=!,B=),,<*#X/],,=I(
M`=!,`<A(`P9(@\8(C2P(3(G02<'J`DC!X!Y)"<)(B>I(B>A(P>H;2,'@!4&#
MXO]("=!(B=I,,=*#X/],,<)(`=!,`=A(`P9(@\8(1(T,"$B)V$C!ZP)(P>`>
M2`G#3(G*3(G(2,'J&TC!X`6#X_]("=!(B>I(,=J#X/],,=)(`=!,`<!(`P9(
M@\8(1(T<"$B)Z$C![0)(P>`>2`G%3(G:3(G82,'J&TC!X`6#Y?]("=!,B<I(
M,>J#X/](,=I(`=!,`=!(`P9(@\8(1(T$"$R)R$G!Z0)(P>`>20G!3(G"3(G`
M2,'J&TC!X`5!@^'_2`G03(G:3#'*@^#_2#'J2`'02`'82`,&2(/&"$2-%`A,
MB=A)P>L"2,'@'DD)PTR)TDR)T$C!ZAM(P>`%08/C_T@)T$R)PDPQVH/@_TPQ
MRD@!T$@!Z$@#!DB#Q@B-'`A,B<!)P>@"2,'@'DD)P$B)VDB)V$C!ZAM(P>`%
M08/@_T@)T$R)TDPQPH/@_TPQVD@!T$P!R$@#!DB#Q@B-+`A,B=!)P>H"2,'@
M'DD)PDB)ZDB)Z$C!ZAM(P>`%08/B_T@)T$B)VDPQTH/@_TPQPD@!T$P!V$@#
M!DB#Q@A$C0P(2(G82,'K`DC!X!Y("<-,B<I,B<A(P>H;2,'@!8/C_T@)T$B)
MZH/@_T@QVDPQTD@!T$P!P$@#!DB#Q@A$C1P(2(GH2,'M`DC!X!Y("<5,B=I,
MB=A(P>H;2,'@!8/E_T@)T$R)RD@QZH/@_T@QVD@!T$P!T$@#!DB#Q@A$C00(
M3(G(2<'I`DC!X!Y)"<%,B<),B<!(P>H;2,'@!4&#X?]("=!,B=I,,<J#X/](
M,>I(`=!(`=A(`P9(@\8(1(T4"$R)V$G!ZP)(P>`>20G#3(G23(G02,'J&TC!
MX`5!@^/_2`G03(G"3#':@^#_3#'*2`'02`'H2`,&2(/&"(T<"$R)P$G!Z`)(
MP>`>20G`2(G:2(G82,'J&TC!X`5!@^#_2`G03(G23#'"@^#_3#':2`'03`'(
M2`,&2(/&"(TL"$R)T$G!Z@)(P>`>20G"2(GJ2(GH08/B_TC!ZAM(P>`%2`G0
M2(G:3#'2@^#_3#'"2`'03`'82`,&2(/&"$2-#`A(B=A(P>L"2,'@'D@)PTR)
MRDR)R$C!ZAM(P>`%@^/_2`G02(GJ2#':@^#_3#'22`'03`'`2`,&2(/&"$2-
M'`A(B>A(P>T"2,'@'D@)Q4R)VDR)V$C!ZAM(P>`%@^7_2`G03(G*@^#_2#'J
M2#':2`'03`'02`,&1(T$"$R)R$G!Z0)(P>`>20G!3(G"3(G`2,'J&TC!X`5!
M@^'_2`G03(G:3#'*@^#_2#'J2`'03(G:2<'K`D@!V$@#1@A(P>(>3`G:1(T4
M"$&+!"1$`=!)B00D08M$)`A!`U0D$$0!P$F)1"0(08M$)!A)B50D$$0!R$F)
M1"0808M$)"`!Z$F)1"0@2('$"`(``%M=05S#9F9FD%,QV^@$W/__B<?HW=W_
M_TB%P'0#2(L82(G86\-F9F:02(E<)/!(B6PD^$B![)@```!(B>9(B?LQ[>B>
MW/__A<!U(`^W1"0()0#P```]`$````^4PCT`H```#Y3`"="H`74>B>A(BYPD
MB````$B+K"20````2('$F````,-F9F:02(G?O@(```#HS]W__X7`N`$```!(
MBYPDB`````]$Z(GH2(NL))````!(@<28````PV9F9I!F9F:09F9FD&9FD$%6
M28G^055%,>U!5$&\%5-``%532(/L,(`]5A,```!(QP0D%5-``$C'1"0("U-`
M`$C'1"00&%-``$C'1"08#E-``$C'1"0@$U-``$C'1"0HLE-``'0U,<!,B>?H
M4.#__TB%P$B)Q70%@#@`=2M,B?9,B><QP.A6X/__0?_%26/%3(LDQ$&`/"0`
M=<M(@\0P6UU!7$%=05[#3(GV2(G'Z(G;__](A<!UTDR)]^@LW?__2(L]L7`0
M`$B)P^@=W?__2(GO2`'#Z!+=__](C7P#`>B8VO__2(L-C7`0`$B)P[Y?4T``
M2(G'28GH3(GR,<#H6=S__TB)WNEU____9F:09I!!5S'`059)B?Z_*E)``$%5
M13'M05154TB![&B!``!(QX0D0($``"530`!(QX0D2($``"U30`!(QX0D4($`
M`*130`!(QX0D6($``+)30`!(QX0D$($``-)20`!(QX0D&($``,M20`!(QX0D
M(($``#=30`!(QX0D*($``"A30`!(QX0D,($``#]30`!(QX0D.($``+)30`!(
MQX0D\(```$-30`!(QX0D^(```$A30`!(QX0D`($``+)30`#H\=[__TB%P$B)
MPW0)@#@`#X7/`@``,<#H:?W__TB%P$F)Q'1'00^V!"1,B>/K'F9F9I!F9I#H
M9]K__R4`!0``A<!U`\8#7TC_PP^V`X3`=&4/OOB!__\```!WVDB+!<-W$`!(
M8]>+1-!`Z\](B[PD\(```#'M@#\`="XQP.ATWO__2(7`=`M(B<?H@]K__TF)
MQ/_%387D=8Q(8\5(B[S$\(```(`_`'720;Q14T``9F9FD&9FD$B+O"00@0``
M,>V`/P!T-Y`QP.@IWO__2(7`2(G#=!!(B<?HR?S__X7`#X7H`0``_\5-A>UU
M$$ACQ4B+O,00@0``@#\`=<HQ[4V%[0^$``(``$R)[^@3V___OUA30`!(B</H
M!MO__TR)YP'#Z/S:__^_LE-```'#Z/#:__^-A`,`!```2&/82(G?Z&[8__](
MB=])B<?H8]C__TB+#5!N$`!-B>%!N%A30`!,B>I(B<=(B40D&+Y=4T``,<#H
M'-K__TB+?"08ONT!``#H_=K__S'`OPY30`#H9=W__TB%P`^$0P$``$B)Q^AP
MV?__28L^2(G&Z&G@__](A<!(B<,/A"0!``!(B=_H8=K__X/X!$&)P'P>2&/P
MN`4```"_9E-``$B-=![\2(G!_/.F#X1U`0``,<#H6.3__X7`=18Q]DB)W^@V
MVO__A<")1"04#X6O`0``ONU20`"_?5)``#'`Z/W<___H)-?__TB+#8%M$`!(
MBU0D&$&)P$&YLE-``+YK4T``3(G_,<`QV^A.V?__ZT#H-]C__X,X$75'9F:0
M9F:0Z.?6__](BPU$;1``2(M4)!C_PT&)P$&)V;YY4T``3(G_,<!(QP0DLE-`
M`.@,V?__ONT!``!,B?_H[]G____`=*](BWPD&.@1VO__3(G^ORI20``QP.AF
MW/__3(G_Z([[__](@<1H@0``3(GX6UU!7$%=05Y!7\-(B=_H/=C__TF)Q>D(
M_O__28L>Z=3^__](B<?H6?O__TB)W^@=V/__2('$:($``%M=05Q!74%>05_#
M2(N<)$"!``"`.P`/A._]__](B=_HAOK__X7`=2O_Q4V%[0^%V/W__TACQ4B+
MG,1`@0``@#L`#X3$_?__2(G?Z%OZ__^%P'352(G?Z+O7__])B<7KR$&#^`1T
M&TB+%3UL$`!!@^@$26/`#[82.%08_P^%:O[__TF+;@A(A>T/A%W^__](B>_H
MD-C__TB#^`,/ADO^__](C70%_+^*4T``N04```#\\Z9(#T3=Z3#^__^Z`@``
M`$C'QN[___^)Q^@XUO__BWPD%$B-="1`N@8```#HM=;__X!\)$``=0N`?"1!
M0P^$OP,``(M\)!0QTC'V3(VL)$"```#H_M7__[Z)J\WON?[<NIBZ\.'2PTC'
MA"1`@````2-%9TB)M"1(@```2(F,)%"```!(QX0D6(```'94,A!(B90D8(``
M`$C'A"1H@````````$C'A"1P@````````,>$)+B`````````BWPD%$B-="1`
MN@"```#H&=;__X7`2(G'08G&#XZZ````2(N,)&B```!)8]9(BX0D<(```$R-
M9"1`B?V---%(.<Y(B;0D:(```$B#T`!(P>H=2(F$)'"```"+A"2X@```2`&4
M)'"```"%P`^$G0(``+M`````2(UT)$!$B?4IPT0Y\P]/WTAC^$QCXTJ-?"\X
M*=U,B>+H8M3__P.<)+B```!(C40D0$Z-)""#^T")G"2X@```#X1+`@``BWPD
M%$B-="1`N@"```#H7]7__X7`2(G'08G&#X]&____BWPD%$B-7"0@Z%/7__](
MBZPD:(```$R+I"1P@```2(GH2,'H`XG!@^$_2&/!_\&#^3A"QD0H.(`/CA$"
M``!(8_FZ0````#'V*<I*C7PO.$ACTNB:U?__3(GOZ/;@__])C7TXN0<````Q
MP/SS2*M,B>!!B&UW18AE<TC!Z!A,B>]!B$5P3(G@2,'H$$&(17%,B>!(P>@(
M08A%<DB)Z$C!Z!A!B$5T2(GH2,'H$$&(175(B>A(C:PDP(```$C!Z`A!B$5V
MZ(W@__])BU4`2(G0B%,#2,'H&(@#2(G02,'H$(A#`4B)T$C!Z`B(0P))BU4(
M2(G0B%,'2,'H&(A#!$B)T$C!Z!"(0P5(B=!(P>@(B$,&28M5$$B)T(A3"TC!
MZ!B(0PA(B=!(P>@0B$,)2(G02,'H"(A#"DF+51A(B="(4P](P>@8B$,,2(G0
M2,'H$(A##4B)T$C!Z`B(0PY)BU4@2(G0B%,32,'H&(A#$$B)T$C!Z!"(0Q%(
MB=!(P>@(B$,2,=MF9I!(8\.-/!N^CU-```^V5`0@_\,QP$AC_TB-?#T`Z*O4
M__^#^Q-^VL:$).B`````0;FR4T``28GH2(L-HF@0`$B+5"08OI130`!,B?\Q
MP.AZU/__Z7K[__])BP0D@^U`28E%.$F+1"0(28E%0$F+1"0028E%2$F+1"08
M28E%4$F+1"0@28E%6$F+1"0H28E%8$F+1"0P28E%:$F+1"0X28/$0$F)17!,
MB>_H(]___X/]/W^E28U].$ACU4R)YNC;T?__08EM>.G6_/__2&/YNC@````Q
M]BG*2HU\+SA(8]+HB=/__^D!_O__@'PD0D$/A3;\__^`?"1#0P^%*_S__X!\
M)$1(#X4@_/__@'PD145FD`^%$_S__XM\)!2Z`@```$C'QL;____H$=+__XM\
M)!1(C70D0+HI````Z([2__],C40D0$&YLE-``.GI_O__9I!!54%428G\55-(
M@>R(````2(7_=`6`/P!U#DB!Q(@```!;74%<05W#Z`_3__](A<!)B<5TY4R)
M[^B/T?__2(7`#X38````2(U8"+^D4T``N0(```#\2(G>\Z9TV;^C4T``N0,`
M``!(B=[SIG3(3(GGZ)?3__](B=E(B<9F9I!FD(L!2(/!!(V0__[^_O?0(<*!
MXH"`@(!TZ(G0P>@0]\*`@```#T302(U!`D@/1,@`TDB#V0-(*=F-/`Z#QP)(
M8__HU]#__TB)V4B)QTB)Q4R)XKZF4T``,<#HG]+__TB)YDB)[^C$TO___\!T
M$0^W1"0()0#P```]`$```'0_2(GOZ+?1__](B>_HC]/__TR)[^BWT/__2(7`
M#X4H____3(GOZ!;3__],B>?HCM#__TB!Q(@```!;74%<05W#2(GOZ+S^___K
MOV9F9I!F9I!F9I!(B5PD\$B);"3X2(/L&$B)^^A:VO__2(G'Z!+:__](B<4Q
MP.BXW/__A<!T'$B%VW07@#L`=!*^6%-``$B)[^C)T/__2#GH=`](BUPD"$B+
M;"002(/$&,-(B=](BVPD$$B+7"0(2(/$&.E#_O__9F:02(L%66X0`%,Q]K^R
M4T``2(M0"`^V!4]N$`"(0B!(BP4\;A``2(M0"$B+!5EN$``/MT`@)?\!``!F
MB4(B2(L%'6X0`$B+6`CH`-#__S')2(E#*$B+!0=N$`!(BU`(2(L%-&X0`$B)
M0C!(BP7Q;1``2(M0"$B+!<9M$`!(A<!T!TB+B*@```!(B4HX2(L%SVT0`$B+
M0`A(QT!``````$B+!;QM$`!(BT`(2,=`2`````!(BP6I;1``2(M0"$B+!<YM
M$`!(B4)06\-F9F:09F9FD$B#[`B______^@^S___,?:_,$M``$B#Q`CI/M'_
M_V:0054QP+]A4D``051%,>154TB#[`C&!5UM$``!Z!#4__](A<!T"8`X,0^$
MJ`$``#'`Z+O9__^Z"P```+X!````OZQ30`#HH]#__TB%P`^$H0```(L5^'$0
M`$B+0!"[`0```#G33(MH*'UG,>WK+V9FD$B+=Q!(BP7=<1``2&/32(L\T.@5
MT/__A<!U/(L5OW$0`/_#0?_$_\4YTWTT,=*)[DR)[^BDT/__2(7`=!I(BSCV
M1PT$=;HQ]KH"````Z)K-__](B<;KK8L5@W$0`&9FD(U"_T0YX'4;NP$````Y
MTWT23(GO_\/HH<W__SL=7W$0`'SNN@4```"^`0```+^Q4T``Z.7/__](A<!(
MB<5T(DB+0!"^LU-``$B+..A,SO__2(M%$$B+./9'#D`/A;0```"Z!0```+X!
M````OZU20`#HI\___TB%P$B)Q70G,<"_,U)``.C7TO__2(7`2(G##X20````
M2(M%$$B)WDB+..CXS?__,<"_*E)``,8%]FL0``!(QP6[:Q```````.B>TO__
M2(7`2(D%K'`0``^$D@```+[M`0``2(G'Z`W0__^%P(G##Y7",<"#^Q$/E<"%
MPG0)@_O_#X7$````2(/$"%M=05Q!7<.`>`$`#X15_O__Z4G^___HPLS__V9F
MD&9FD.D\____Z$;5__](A<!(B<-T'$B+11!(B=Y(BSCH6\W__TB)W^C3S___
MZ5;___](BU402(L%+W`0`$B+.DB+,.D[____2(L]'7`0`.A`\O__2(D%`7`0
M`$B+11!(BSCV1PT$=&9(BW\02(LU^6\0`.@8S___B<-(BT402(LX]D<-!'0V
M2(M7$$B+!=IO$`")V;\`5$``2(LP,<#HO<O__TB+!<)O$`!(BQ6K;Q``B=F_
M,%1``$B+,.O?N@(````Q]NBGR___2(G"Z[VZ`@```#'VZ);+__](B<?KC69F
MD&:02(/L".A7T/__13'`N;)30`"ZLE-``+X@3$``O[A30`!(@\0(Z>/+__]F
M9F:09F:04TB#["")?"0,2(ET)!!(C7PD#$B)5"082(UT)!!(C50D&.AES/__
M@#TJ:A````^$;0$``(M\)`R`#2EJ$``#C4<%2&/02(72#XB-`0``\D@/*L+R
M#U@%!04``&8/+@4%!0``#X>?`0``@\<%2&/_2,'G`^@TSO__2(MT)!!(B<%(
MB071;A``0;@!````2(L&2,=!",U30`!(QT$0H%1``$C'01C04T``2(D!BWPD
M#+@$````QP62;A``!````$$Y^'P4ZSU(BPV,;A``2(MT)!"+!7EN$`!)8]!!
MC00`0?_`2(L4UDB82(E4P?B+?"0,03GX?-!(BPU<;A``BP5.;A``C00'13'`
MOO!.0`!(F$C'1,'X`````(L5,FX0``-4)`Q(BPTO;A``2(L]$&X0`/_*Z!7+
M__^%P(G##X2T````2(L]^&T0`.AOS/__,<"_<5)``.C7S___2(7`=2I(BSWC
M;1``2(7_=1F_*E)``.B\S___2(7`2(G'2(D%QVT0`'0%Z!CZ__](BSVQ;1``
MZ#C-___H`\W__XG82(/$(%O#Z&;,__](A<!(B<=(B06-;1``=&3H0LK__XM\
M)`R`#:-H$``#Q@5T:!```(U'!4ACT$B%T@^)<_[__TB)T(/B`4C1Z$@)T/)(
M#RK`\@]8P.E>_O__2(L]1&T0`.@KR___B</I.?___[Z@N5``OR=20``QP.@S
MR?__0+<!Z`O,__^0D)"0D)"0D)"0D)"0D)!52(GE4TC'PT"W4`!(@^P(2(L%
MV640`.L09F9FD&9FD$B#ZPC_T$B+`TB#^/]U\4B#Q`A;R<.0D$B#[`CH'\W_
M_TB#Q`C#`````````````"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]A;60V-"]C
M<G1I+E,L=B`Q+C<N,C0N,2`R,#`X+S$P+S`R(#`R.C4W.C(T(&ME;G-M:71H
M($5X<"`D`#H`<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!F:6QE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10!015),
M-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%2
M7T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`#$`4$%27T=,3T)!
M3%]#3$5!3@!005)?0TQ%04X]`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`
M0SI<5$5-4``O=F%R+W1M<"\`5$5-4$1)4@!435``55-%4@!54T523D%-10!3
M65-414T`<&%R+0`E<R5S)7,E<P!P87)L`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`N<&%R`"4P,G@`)7,E<V-A8VAE+25S)7,`+BX`)7,O)7,`
M05)'5@`8`'!E<FP`26YT97)N86QS.CI005(Z.D)/3U0`+64`+2T```````!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````)7,Z(&5X
M96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`````````````````````
M`,!#`````````````````````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P
M;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE
M<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U
M.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@
M("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER
M(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@
M("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE
M=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E
M8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P
M;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@
M("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S
M92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C
M;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T
M:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7
M:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@
M("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@
M(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@
M/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I
M.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@
M9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@
M+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W
M,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@
M)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*
M"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN
M:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%
M3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?
M05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@
M/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%
M3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F
M:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@
M/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T
M<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@
M>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP
M92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*
M("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M
M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C
M:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*
M("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@
M("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@
M("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@
M)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V
M960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@
M(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M
M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@
M("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U
M;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.
M0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*
M("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@
M("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@
M("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@
M("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@
M<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N
M86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@
M("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@
M0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*
M"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R
M;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R
M97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D
M=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@
M(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@
M<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R
M;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@
M1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B
M;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@
M(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@
M("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?
M<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P
M87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P
M<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'
M5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C
M;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET
M<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N
M;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?
M=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@
M("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A
M;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G
M<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@
M("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U
M;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@
M("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D
M8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S
M:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@
M("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@
M("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!8
M6%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P
M=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@
M9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@
M("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E
M<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@
M(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@
M("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*
M("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM[
M"B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*
M("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M"B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D
M(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@
M,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L
M;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y
M*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D
M9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]
M"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U
M;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I
M;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY
M($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N
M9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.
M+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S
M:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C
M($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@
M("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T
M;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4
M:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F
M('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O
M=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN
M9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@
M)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL
M97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F
M;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@
M("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@
M(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE
M?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I
M;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q
M*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N
M=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@
M("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*
M"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A
M9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO
M9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I
M(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@
M("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@
M3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@
M("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@
M("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@
M(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@
M9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B
M0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO
M<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET
M.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@
M8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@
M4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@
M("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER
M92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@
M("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H
M<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@
M("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*
M("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@
M(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@
M("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@
M("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I
M;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@
M?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@
M("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T
M:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E
M<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB
M.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R
M.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@
M("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER
M92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R
M97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E
M<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@
M("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@
M871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A
M;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES
M(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E
M(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP
M7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@
M("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*
M"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@
M(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W
M=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@
M("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*
M("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92([
M"B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@
M("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F
M:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L
M(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@
M("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@
M("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N
M,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@
M("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@
M("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@
M("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@
M("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@
M?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@
M("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA
M;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*
M("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I
M;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE
M+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@
M*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*
M("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B
M:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC
M('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P
M<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D
M<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@
M("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F
M:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@
M("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@
M("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@
M("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@
M("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@
M(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K
M"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP
M*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N
M=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]
M"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@
M("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@
M("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D
M96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES
M=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T
M=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN
M="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I
M;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER
M92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E
M>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N
M;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q
M,#$R"@I?7T5.1%]?"@!P87(N<&P`)$9R965"4T0Z('-R8R]L:6(O8W-U+V%M
M9#8T+V-R=&XN4RQV(#$N-BXR-"XQ(#(P,#@O,3`O,#(@,#(Z-3<Z,C0@:V5N
M<VUI=&@@17AP("0`````````LE-``````````````````%BW4```````-5-`
M``````#Q44```````/____\`````Z5L```````"*L$```````!0`````````
M`0`!>!`,!PB0`0```````"0````<````(!Y```````",`````````$(.$(P"
M10X800X@@P2&`P`<````1````+`>0```````20````````!(#A"&`D,-!AP`
M``!D`````!]```````!"`````````$$.$(8"2PT&%````(0```!0'T``````
M`!0`````````)````)P```!P'T```````-L`````````2H\"C01>#D".`XP%
MA@:#!QP```#$````4"!````````5`````````$0.$```````/````.0```!P
M($```````.8!````````0@X01`X8C@./`D4.((T$10XH00XP00XX1`Y`@P>&
M!HP%`````````!P````D`0``8")```````!$`````````$$.$(,"1PX@)```
M`$0!``"P(D```````*8`````````5@[`$(P"A@.#!````````!0```!L`0``
M8"-````````%`````````#0```"$`0``<"-```````!V`0```````$(.$$0.
M&$(.($$.*(8%C`2-`XX"20XP@P9*#K`)````%````+P!``#P)$```````#L`
M````````)````-0!```P)4```````-0`````````00X000X8@P.&`D<.(```
M`!P```#\`0``$"9```````"/`0```````$0.0```````'````!P"``"@)T``
M`````$4`````````1`X0```````L````/`(``/`G0```````[!8```````!"
M#A",`DH.&$$.($<.J`2#!(8#```````<````;`(``.`^0```````'```````
M``!!#A"#`@```!P```",`@```#]```````"1`````````%$.H`&&`H,#-```
M`*P"``"@/T```````/L`````````0@X0C@)%#AB-`T4.((P$1PXH00XP1`Y@
M@P:&!0`````\````Y`(``*!`0```````S@@```````!"#A!$#AB.`X\"2@X@
MC01%#BA!#C!!#CA'#J"#`H,'A@:,!0``````+````"0#``!P24```````$8!
M````````0@X00@X8C`.-`D0.($$.*$<.L`&#!88$'````%0#``#`2D``````
M`&T`````````3@X@A@*#`P`<````=`,``#!+0```````R`````````!(#A"#
M`@```!P```"4`P```$Q````````>`````````$0.$```````+````+0#```@
M3$```````,L"````````0@X020X8C`.-`D0.($$.*$0.,(,%A@0`'````.0#
M``#P3D```````"D`````````1`X0```````<````!`0``"!/0```````(0(`
M``````!!#A!$#C"#`@`````0``````````$``7@0#`<(D`$``"P````8````
M4%%````````V``````````0!````#A"&`@0#````#08$`0```(,#``$`````
M`````0`````````!`````````"(#`````````0`````````L`P````````$`
M````````20,````````!`````````%8#````````#P````````";`P``````
M``P`````````2!I````````-`````````(A10```````!`````````#``4``
M``````4`````````L`Y````````&`````````/`$0```````"@````````#6
M!`````````L`````````&``````````5`````````````````````P``````
M``!HMU````````(`````````B`4````````4``````````<`````````%P``
M``````#`%$````````<`````````B!-````````(`````````#@!````````
M"0`````````8````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/__________``````````#_________
M_P````````````````````"0M5````````````````````````````!R&D``
M`````((:0```````DAI```````"B&D```````+(:0```````PAI```````#2
M&D```````.(:0```````\AI````````"&T```````!(;0```````(AM`````
M```R&T```````$(;0```````4AM```````!B&T```````'(;0```````@AM`
M``````"2&T```````*(;0```````LAM```````#"&T```````-(;0```````
MXAM```````#R&T````````(<0```````$AQ````````B'$```````#(<0```
M````0AQ```````!2'$```````&(<0```````<AQ```````""'$```````)(<
M0```````HAQ```````"R'$```````,(<0```````TAQ```````#B'$``````
M`/(<0````````AU````````2'4```````"(=0```````,AU```````!"'4``
M`````%(=0```````8AU```````!R'4```````((=0```````DAU```````"B
M'4```````+(=0```````PAU```````#2'4```````.(=0```````\AU`````
M```"'D```````!(>0```````````````````)$9R965"4T0Z('-R8R]L:6(O
M8W-U+V-O;6UO;B]C<G1B<F%N9"YC+'8@,2XT+C$P+C$N,BXQ(#(P,#@O,3`O
M,#(@,#(Z-3<Z,C0@:V5N<VUI=&@@17AP("0`)$9R965"4T0Z('-R8R]L:6(O
M8W-U+V%M9#8T+V-R=#$N8RQV(#$N,30N,C`N,2`R,#`X+S$P+S`R(#`R.C4W
M.C(T(&ME;G-M:71H($5X<"`D`$=#0SH@*$=.52D@,RXT+C8@6T9R965"4T1=
M(#(P,#8P,S`U``!'0T,Z("A'3E4I(#,N-"XV(%M&<F5E0E-$72`R,#`V,#,P
M-0``1T-#.B`H1TY5*2`S+C0N-B!;1G)E94)31%T@,C`P-C`S,#4``$=#0SH@
M*$=.52D@,RXT+C8@6T9R965"4T1=(#(P,#8P,S`U``!'0T,Z("A'3E4I(#,N
M-"XV(%M&<F5E0E-$72`R,#`V,#,P-0``+G-H<W1R=&%B`"YI;G1E<G``+FYO
M=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR
M96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YD871A`"YE:%]F
M<F%M90`N9'EN86UI8P`N8W1O<G,`+F1T;W)S`"YJ8W(`+F=O=``N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M````````````````````````````````````````````"P````$````"````
M`````)`!0```````D`$````````5`````````````````````0``````````
M`````````!,````'`````@````````"H`4```````*@!````````&```````
M``````````````0````````````````````A````!0````(`````````P`%`
M``````#``0```````"P#````````!``````````(``````````0`````````
M)P````L````"`````````/`$0```````\`0```````#`"0````````4````!
M````"``````````8`````````"\````#`````@````````"P#D```````+`.
M````````U@0```````````````````$````````````````````W````!```
M``(`````````B!-```````"($P```````#@!````````!``````````(````
M`````!@`````````00````0````"`````````,`40```````P!0```````"(
M!0````````0````)````"``````````8`````````$L````!````!@``````
M``!(&D```````$@:````````$P````````````````````0`````````````
M``````!&`````0````8`````````7!I```````!<&@```````,`#````````
M```````````$`````````!``````````40````$````&`````````"`>0```
M````(!X```````!H,P``````````````````$````````````````````%<`
M```!````!@````````"(44```````(A1````````#@``````````````````
M``0```````````````````!=`````0````(`````````H%%```````"@40``
M`````$)?```````````````````@````````````````````90````$````#
M`````````.BP4```````Z+````````!`````````````````````"```````
M`````````````&L````!`````@`````````HL5```````"BQ````````:`0`
M``````````````````@```````````````````!U````!@````,`````````
MD+50``````"0M0```````+`!````````!0`````````(`````````!``````
M````?@````$````#`````````$"W4```````0+<````````0````````````
M````````"````````````````````(4````!`````P````````!0MU``````
M`%"W````````$`````````````````````@```````````````````",````
M`0````,`````````8+=0``````!@MP````````@````````````````````(
M````````````````````D0````$````#`````````&BW4```````:+<`````
M``#P`0``````````````````"``````````(`````````)8````(`````P``
M``````!@N5```````&"Y````````*`4``````````````````"``````````
M``````````";`````0````````````````````````!@N0```````&4!````
M```````````````!`````````````````````0````,`````````````````
M````````Q;H```````"D`````````````````````0``````````````````
!````
